@@ -65,7 +65,7 @@ typedef struct
   char *value2;
   int value2Length;
 }
-FileInfo;
+lbu_FileInfo;
 
 static char pathEnd[2];
 static double paperWidth;
@@ -78,7 +78,7 @@ static int errorCount = 0;
 static int fatalErrorCount = 0;
 
 static void
-configureError (FileInfo * nested, char *format, ...)
+configureError (lbu_FileInfo * nested, char *format, ...)
 {
   char buffer[1024];
   va_list arguments;
@@ -90,9 +90,9 @@ configureError (FileInfo * nested, char *format, ...)
 #endif
   va_end (arguments);
   if (nested)
-    logMessage (LOG_ERROR, "%s:%d: %s", nested->fileName, nested->lineNumber, buffer);
+    logMessage (LOU_LOG_ERROR, "%s:%d: %s", nested->fileName, nested->lineNumber, buffer);
   else
-    logMessage (LOG_ERROR, "%s", buffer);
+    logMessage (LOU_LOG_ERROR, "%s", buffer);
   errorCount++;
 }
 
@@ -215,7 +215,7 @@ find_file (const char *fileName, char *filePath)
 }
 
 static char *
-findTable (FileInfo * nested)
+findTable (lbu_FileInfo * nested)
 {
   char trialPath[MAXNAMELEN];
   char filePath[MAXNAMELEN];
@@ -253,7 +253,7 @@ findTable (FileInfo * nested)
 }
 
 static int
-controlCharValue (FileInfo * nested)
+controlCharValue (lbu_FileInfo * nested)
 {
 /*Decode centrol characters*/
   int k = 0;
@@ -295,13 +295,13 @@ controlCharValue (FileInfo * nested)
   return 1;
 }
 
-static int compileConfig (FileInfo * nested);
+static int compileConfig (lbu_FileInfo * nested);
 
 int
 config_compileSettings (const char *fileName)
 {
 /*Compile an input file or string */
-  FileInfo nested;
+  lbu_FileInfo nested;
   char completePath[MAXNAMELEN];
   if (!*fileName)
     return 1;			/*Probably run with defaults */
@@ -329,7 +329,7 @@ config_compileSettings (const char *fileName)
 }
 
 static int
-getLine (FileInfo * nested)
+getLine (lbu_FileInfo * nested)
 {
   int lineLen = 0;
   int ch;
@@ -369,7 +369,7 @@ getLine (FileInfo * nested)
 }
 
 static int
-parseLine (FileInfo * nested)
+parseLine (lbu_FileInfo * nested)
 {
   char *curchar = NULL;
   int ch = 0;
@@ -468,7 +468,7 @@ find_action (const char **actions, const char *action)
 }
 
 static int
-checkActions (FileInfo * nested, const char **actions)
+checkActions (lbu_FileInfo * nested, const char **actions)
 {
   int actionNum = find_action (actions, nested->action);
   if (actionNum == -1)
@@ -477,7 +477,7 @@ checkActions (FileInfo * nested, const char **actions)
 }
 
 static int
-checkValues (FileInfo * nested, const char **values)
+checkValues (lbu_FileInfo * nested, const char **values)
 {
   int k;
   for (k = 0; values[k]; k += 2)
@@ -494,7 +494,7 @@ checkValues (FileInfo * nested, const char **values)
 }
 
 static unsigned int
-hexValue (FileInfo * nested, const char *digits)
+hexValue (lbu_FileInfo * nested, const char *digits)
 {
   int length = strlen (digits);
   int k;
@@ -520,7 +520,7 @@ hexValue (FileInfo * nested, const char *digits)
 }
 
 static unsigned int
-convertValue (FileInfo * nested, const char *number)
+convertValue (lbu_FileInfo * nested, const char *number)
 {
   if (number[0] == '0' && number[1] == 'x')
     return hexValue (nested, &number[2]);
@@ -534,7 +534,7 @@ convertValue (FileInfo * nested, const char *number)
 }
 
 static int
-orValues (FileInfo * nested, const char **values)
+orValues (lbu_FileInfo * nested, const char **values)
 {
   int result = 0;
   int k;
@@ -564,7 +564,7 @@ orValues (FileInfo * nested, const char **values)
 }
 
 static int
-checkSubActions (FileInfo * nested, const char **mainActions, const char
+checkSubActions (lbu_FileInfo * nested, const char **mainActions, const char
 		 **subActions)
 {
   int subAction;
@@ -588,7 +588,7 @@ checkSubActions (FileInfo * nested, const char **mainActions, const char
 }
 
 static int
-compileConfig (FileInfo * nested)
+compileConfig (lbu_FileInfo * nested)
 {
   static const char *mainActions[] = {
     "outputFormat",
@@ -1313,7 +1313,7 @@ read_configuration_file (const char *configFileList, const char
   char subFile[MAXNAMELEN];
   int listLength;
   int currentListPos = 0;
-  logMessage(LOG_INFO, "Begin read_configuration_file");
+  logMessage(LOU_LOG_INFO, "Begin read_configuration_file");
   errorCount = 0;
   fatalErrorCount = 0;
   /*Process logFileName later, after writeablePath is set */
@@ -1357,7 +1357,7 @@ read_configuration_file (const char *configFileList, const char
       StyleType *style = new_style ((xmlChar *) semNames[k]);
       style->action = k;
     }
-  ud->input_encoding = utf8;
+  ud->input_encoding = lbu_utf8;
   ud->output_encoding = ascii8;
   *ud->print_page_number = '_';
   *ud->print_page_number_first = '_';
@@ -1431,6 +1431,7 @@ read_configuration_file (const char *configFileList, const char
     }
   memset (ud->typeform, 0, sizeof (ud->typeform));
   ud->braille_page_number = ud->beginning_braille_page_number;
+  ud->page_number = 1;
   if (entities)
     strcat (ud->xml_header, "]>\n");
   ud->mode = mode | ud->config_mode;
@@ -1463,7 +1464,7 @@ read_configuration_file (const char *configFileList, const char
       if (ud->page_right <= 0 || ud->page_bottom <= 0)
 	{
 	  logMessage
-	    (LOG_ERROR, "For UTDML paper witdth and paper height must be specified.");
+	    (LOU_LOG_ERROR, "For UTDML paper witdth and paper height must be specified.");
 	  lbu_free ();
 	  return 0;
 	}
@@ -1473,6 +1474,6 @@ read_configuration_file (const char *configFileList, const char
       ud->back_text = textDevice;
       ud->back_line_length = 70;
     }
-  logMessage(LOG_INFO, "Finish read_configuration_file");
+  logMessage(LOU_LOG_INFO, "Finish read_configuration_file");
   return 1;
 }
