@@ -198,7 +198,7 @@ transcribe_paragraph (xmlNode * node, int action)
   xmlNode *child;
   int branchCount = 0;
   int i;
-  logMessage(LOG_DEBUG, "Begin transcribe_paragraph");
+  logMessage(LOU_LOG_DEBUG, "Begin transcribe_paragraph");
   if (node == NULL)
     return 0;
   if (ud->top == 0)
@@ -227,7 +227,7 @@ transcribe_paragraph (xmlNode * node, int action)
       ud->main_braille_table = ud->contracted_table_name;
       if (!lou_getTable (ud->main_braille_table))
 	{
-	  logMessage (LOG_ERROR, "Cannot open main table %s", ud->main_braille_table);
+	  logMessage (LOU_LOG_ERROR, "Cannot open main table %s", ud->main_braille_table);
 	  return 0;
 	}
       if (node->children == NULL)
@@ -338,7 +338,7 @@ transcribe_paragraph (xmlNode * node, int action)
   if (is_macro (node))
     {
       haveMacro = 1;
-      logMessage(LOG_DEBUG, "Node has macro");
+      logMessage(LOU_LOG_DEBUG, "Node has macro");
       start_macro (node);
     }
   else if ((style = is_style (node)) != NULL)
@@ -349,7 +349,7 @@ transcribe_paragraph (xmlNode * node, int action)
 	    pop_sem_stack ();
 	  return 0;
 	}
-      logMessage(LOG_DEBUG, "Node has style");
+      logMessage(LOU_LOG_DEBUG, "Node has style");
       start_style (style, node);
     }
   child = node->children;
@@ -629,6 +629,6 @@ transcribe_paragraph (xmlNode * node, int action)
       insert_translation (ud->main_braille_table);
       write_paragraph (para, NULL);
     }
-  logMessage(LOG_DEBUG, "Finished transcribe_paragraph");
+  logMessage(LOU_LOG_DEBUG, "Finished transcribe_paragraph");
   return 1;
 }
